<?php

namespace Larareal\Realestate\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Larareal\Realestate\Models\Realestate;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Larareal\Realestate\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/realestate/property/*')) {
            Route::bind('property', function ($property) {
                $propertyrepo = $this->app->make('Larareal\Realestate\Interfaces\PropertyRepositoryInterface');
                return $propertyrepo->findorNew($property);
            });
        }

        if (Request::is('*/realestate/property_category/*')) {
            Route::bind('property_category', function ($property_category) {
                $property_categoryrepo = $this->app->make('Larareal\Realestate\Interfaces\PropertyCategoryRepositoryInterface');
                return $property_categoryrepo->findorNew($property_category);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
